@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2018 Yuan Fu
 
-;; Package-Version: 20251111.2306
-;; Package-Revision: 84bff3a1da2d
+;; Package-Version: 20251218.435
+;; Package-Revision: 595262ec8ff5
 
 ;; Author: Yuan Fu <casouri@gmail.com>
 ;; URL: https://github.com/casouri/eldoc-box
@@ -862,48 +862,59 @@ The position of childframe is at mouse position."
 But only if mouse is currently hovering over a valid
 `eldoc-box-mouse-mode' position. And only triggers if there is not
 already a previous documentation box active."
-  (when (not (eldoc-box--frame-visible-p))
-	(when-let* ((mouse-pos (mouse-pixel-position))
-		        (frame (car mouse-pos))
-		        (xy (cdr mouse-pos))
-		        (posn (and (> (car xy) 0)
-                           (> (cdr xy) 0)
-                           (posn-at-x-y (car xy) (cdr xy) frame)))
-                ;; This can be a frame if x,y is outside of the frame.
-		        (window (and (windowp (posn-window posn))
-                             (posn-window posn)))
-		        (pos (posn-point posn))
-		        (buffer (window-buffer window)))
-	  (when (buffer-local-value 'eldoc-box-mouse-mode buffer)
-		(setq eldoc-box--mouse-location (cons window pos))
-        (with-current-buffer buffer
-          (save-excursion
-		    (goto-char pos)
-            ;; We can’t override the display function here like we
-            ;; do in ‘eldoc-box-help-at-point’, because eldoc doc
-            ;; function might by async.
-		    (when (not (eolp)) (eldoc-print-current-symbol-info))))))))
+  ;; If the Emacs frame is deselected, or some other rare case
+  ;; happens, some value in the logic might get nil and we might get
+  ;; runtime error. In that case just regard it as mouse isn’t
+  ;; hovering anymore and cleanup the childframe.
+  (ignore-errors
+    (when (not (eldoc-box--frame-visible-p))
+	  (when-let* ((mouse-pos (mouse-pixel-position))
+		          (frame (car mouse-pos))
+		          (xy (cdr mouse-pos))
+		          (posn (and (> (car xy) 0)
+                             (> (cdr xy) 0)
+                             (posn-at-x-y (car xy) (cdr xy) frame)))
+                  ;; This can be a frame if x,y is outside of the frame.
+		          (window (and (windowp (posn-window posn))
+                               (posn-window posn)))
+		          (pos (posn-point posn))
+		          (buffer (window-buffer window)))
+	    (when (buffer-local-value 'eldoc-box-mouse-mode buffer)
+		  (setq eldoc-box--mouse-location (cons window pos))
+          (with-current-buffer buffer
+            (save-excursion
+		      (goto-char pos)
+              ;; We can’t override the display function here like we
+              ;; do in ‘eldoc-box-help-at-point’, because eldoc doc
+              ;; function might by async.
+		      (when (not (eolp)) (eldoc-print-current-symbol-info)))))))))
 
 (defun eldoc-box--mouse-still-hovering-p ()
   "Returns non-nil if mouse is still hovering at the same position.
 
 This is used for deciding whether to keep showing the doc childframe."
-  (let* ((mouse-pos (mouse-pixel-position))
-	     (frame (car mouse-pos))
-	     (xy (cdr mouse-pos))
-	     (posn (and (> (car xy) 0)
-                    (> (cdr xy) 0)
-                    (posn-at-x-y (car xy) (cdr xy) frame)))
-	     (window (and (windowp (posn-window posn))
-                      (posn-window posn)))
-	     (pos (posn-point posn))
-	     (buffer (window-buffer window)))
-	(cond
-     ;; Keep the frame if mouse pointer is in it.
-	 ((eldoc-box--pos-in-frame-p xy))
-     ;; Keep the frame if mouse still points to the same position.
-	 ((buffer-local-value 'eldoc-box-mouse-mode buffer)
-	  (eq eldoc-box--last-point pos)))))
+  (condition-case nil
+      (let* ((mouse-pos (mouse-pixel-position))
+	         (frame (car mouse-pos))
+	         (xy (cdr mouse-pos))
+	         (posn (and (> (car xy) 0)
+                        (> (cdr xy) 0)
+                        (posn-at-x-y (car xy) (cdr xy) frame)))
+	         (window (and (windowp (posn-window posn))
+                          (posn-window posn)))
+	         (pos (posn-point posn))
+	         (buffer (window-buffer window)))
+	    (cond
+         ;; Keep the frame if mouse pointer is in it.
+	     ((eldoc-box--pos-in-frame-p xy))
+         ;; Keep the frame if mouse still points to the same position.
+	     ((buffer-local-value 'eldoc-box-mouse-mode buffer)
+	      (eq eldoc-box--last-point pos))))
+    ;; If the Emacs frame is deselected, or some other rare case
+    ;; happens, some value in the logic might get nil and we might get
+    ;; runtime error. In that case just regard it as mouse isn’t
+    ;; hovering anymore and cleanup the childframe.
+    (error nil)))
 
 (defun eldoc-box--mouse-enable ()
   "Enable eldoc-box-mouse.
